pub enum TransactionMode {
ReadOnly,
ReadWrite,
VersionChange,
}Expand description
Specifies the transaction mode.
Variants
ReadOnly
The transaction is only allowed to read data.
ReadWrite
The transaction is allowed to read, modify and delete data from existing object stores.
VersionChange
The transaction is allowed to read, modify and delete data from existing object stores, and can also create and
remove object stores and indexes. This type of transaction can’t be manually created, but instead is created
automatically when an upgradeneeded event is fired.