KeyRange

Struct KeyRange 

pub struct KeyRange { /* private fields */ }
Represents a continuous interval over some data type that is used for keys.

Implementations

Source

impl KeyRange

pub fn only(value: &JsValue) -> Result<KeyRange, Error>

Returns a new KeyRange spanning only key.

pub fn bound( lower: &JsValue, upper: &JsValue, lower_open: Option<bool>, upper_open: Option<bool>, ) -> Result<KeyRange, Error>

Returns a new KeyRange spanning from lower to upper. If lower_open is true, lower is not included in the range. If upper_open is true, upper is not included in the range.

pub fn lower_bound( lower: &JsValue, lower_open: Option<bool>, ) -> Result<KeyRange, Error>

Returns a new KeyRange starting at key with no upper bound. If lower_open is true, key is not included in the range.

pub fn upper_bound( upper: &JsValue, upper_open: Option<bool>, ) -> Result<KeyRange, Error>

Returns a new KeyRange with no lower bound and ending at key. If upper_open is true, key is not included in the range.

pub fn lower(&self) -> Result<JsValue, Error>

Returns the range’s lower bound, or undefined if none.

pub fn upper(&self) -> Result<JsValue, Error>

Returns the range’s upper bound, or undefined if none.

pub fn lower_open(&self) -> bool

Returns the range’s lower open flag.

pub fn upper_open(&self) -> bool

Returns the range’s upper open flag.

pub fn includes(&self, value: &JsValue) -> Result<bool, Error>

Returns true if key is included in the range, and false otherwise.